@@ -251,7 +251,6 @@ public abstract class AbstractMethodDeclaration
 	 */
 	public void generateCode(ClassScope classScope, ClassFile classFile) {
 
-		int problemResetPC = 0;
 		classFile.codeStream.wideMode = false; // reset wideMode to false
 		if (this.ignoreFurtherInvestigation) {
 			// method is known to have errors, dump a problem method
@@ -265,6 +264,16 @@ public abstract class AbstractMethodDeclaration
 			classFile.addProblemMethod(this, this.binding, problemsCopy);
 			return;
 		}
+		int problemResetPC = 0;
+		CompilationResult unitResult = null;
+		int problemCount = 0;
+		if (classScope != null) {
+			TypeDeclaration referenceContext = classScope.referenceContext;
+			if (referenceContext != null) {
+				unitResult = referenceContext.compilationResult();
+				problemCount = unitResult.problemCount;
+			}
+		}
 		boolean restart = false;
 		boolean abort = false;
 		// regular code generation
@@ -280,11 +289,19 @@ public abstract class AbstractMethodDeclaration
 					classFile.contentsOffset = problemResetPC;
 					classFile.methodCount--;
 					classFile.codeStream.resetInWideMode(); // request wide mode
+					// reset the problem count to prevent reporting the same warning twice
+					if (unitResult != null) {
+						unitResult.problemCount = problemCount;
+					}
 					restart = true;
 				} else if (e.compilationResult == CodeStream.RESTART_CODE_GEN_FOR_UNUSED_LOCALS_MODE) {
 					classFile.contentsOffset = problemResetPC;
 					classFile.methodCount--;
 					classFile.codeStream.resetForCodeGenUnusedLocals();
+					// reset the problem count to prevent reporting the same warning twice
+					if (unitResult != null) {
+						unitResult.problemCount = problemCount;
+					}
 					restart = true;
 				} else {
 					restart = false;
@@ -342,6 +359,15 @@ public abstract class AbstractMethodDeclaration
 				classFile.completeCodeAttribute(codeAttributeOffset);
 			} catch(NegativeArraySizeException e) {
 				throw new AbortMethod(this.scope.referenceCompilationUnit().compilationResult, null);
+			} catch (IllegalArgumentException iae) {
+				// TODO debug for 458660
+				String debugString = "";
+				try {
+					debugString = new String(this.binding.declaringClass.sourceName)+"."+new String(this.binding.selector);
+				} catch (Exception e) {
+					new RuntimeException("Unable to produce debug string...").printStackTrace();
+				}
+				throw new IllegalArgumentException("Unable to complete code attribute for "+debugString,iae);
 			}
 			attributeNumber++;
 		} else {
